// 企业路由信息
import Layout from '@/layout/enterprise.vue'

const enterprise = [
  {
    path: '/enterprise',
    show: true,
    redirect: '/enterprise/talentPool',
  },
  {
    path: '/enterprise/talentPool',
    component: Layout,
    name: 'talentPool',
    meta: {
      title: '人才库',
      enName: 'Talent Pool',
      icon: 'mdi-account-multiple-outline'
    },
    children: [
      {
        path: '/enterprise/talentPool',
        show: true,
        component: () => import('@/views/enterprise/talentPool/index.vue')
      },
      {
        path: '/enterprise/talentPool/details/:id',
        show: true,
        component: () => import('@/views/enterprise/talentPool/components/details'),
        name: 'talentPoolDetails',
        meta: {
          title: '人才详情',
          hideSide: true
        }
      }
    ]
  },
  {
    path: '/enterprise/statistics',
    component: Layout,
    name: 'enterpriseStatistics',
    meta: {
      title: '统计分析',
      enName: 'Statistics',
      icon: 'mdi-chart-arc'
    },
    children: [
      {
        path: '/enterprise/statistics/overallAnalysis',
        meta: {
          title: '整体分析'
        },
        component: () => import('@/views/enterprise/statistics/overallAnalysis.vue')
      }
    ]
  },
  {
    path: '/enterprise/position',
    component: Layout,
    name: 'jobManagement',
    meta: {
      title: '职位管理',
      enName: 'Job Management',
      icon: 'mdi-format-list-bulleted-square'
    },
    children: [
      {
        path: '/enterprise/position',
        meta: {
          title: '职位列表'
        },
        component: () => import('@/views/enterprise/positionManagement/index.vue')
      },
      {
        path: '/enterprise/position/add',
        show: true,
        meta: {
          title: '新增职位'
        },
        component: () => import('@/views/enterprise/positionManagement/components/add.vue')
      },
      {
        path: '/enterprise/position/edit',
        show: true,
        meta: {
          title: '职位编辑'
        },
        component: () => import('@/views/enterprise/positionManagement/components/add.vue')
      },
      {
        path: '/enterprise/position/details/:id',
        show: true,
        meta: {
          title: '职位详情'
        },
        component: () => import('@/views/enterprise/positionManagement/components/details.vue')
      }
    ]
  },
  {
    path: '/enterprise/communication',
    component: Layout,
    name: 'Communication',
    meta: {
      title: '沟通',
      enName: 'Communication',
      icon: 'mdi-bell-outline'
    },
    children: [
      {
        path: '/enterprise/communication',
        show: true,
        component: () => import('@/views/enterprise/communication/index.vue')
      }
    ]
  },
  {
    path: '/enterprise/interview',
    component: Layout,
    name: 'interview',
    meta: {
      title: '面试',
      enName: 'interview',
      icon: 'mdi-account-multiple-check'
    },
    children: [
      {
        path: '/enterprise/interview',
        show: true,
        component: () => import('@/views/enterprise/interview/index.vue')
      }
    ]
  },
  {
    path: '/enterprise/personnelManagement',
    component: Layout,
    name: 'personnelManagement',
    meta: {
      title: '牛人管理',
      enName: 'Personnel Management',
      icon: 'mdi-account-settings-outline'
    },
    children: [
      {
        path: '/enterprise/personnelManagement',
        show: true,
        component: () => import('@/views/enterprise/personnelManagement/index.vue')
      }
    ]
  },
  {
    path: '/enterprise/informationManagement',
    component: Layout,
    redirect: '/enterprise/informationManagement/informationSettings',
    name: 'informationManagement',
    meta: {
      title: '信息管理',
      enName: 'Information Management',
      icon: 'mdi-tune'
    },
    children: [
      {
        path: '/enterprise/informationManagement/informationSettings',
        meta: {
          title: '企业信息设置',
          isAdmin: true,
          enName: 'Enterprise Information Settings'
        },
        component: () => import('@/views/enterprise/informationManagement/informationSettings.vue')
      },
      {
        path: '/enterprise/informationSettings',
        meta: {
          title: '个人信息设置',
          enName: 'Personal information settings'
        },
        component: () => import('@/views/enterprise/informationSetting/index.vue')
      }
    ]
  },
  {
    path: '/enterprise/systemManagement',
    component: Layout,
    redirect: '/enterprise/systemManagement/userManagement/index.vue',
    name: 'systemManagement',
    meta: {
      title: '系统管理',
      enName: 'system Management',
      icon: 'mdi-cog-outline',
      isAdmin: true // 企业管理员菜单
    },
    children: [
      {
        path: '/enterprise/systemManagement/userManagement',
        meta: {
          title: '用户管理',
          enName: 'User Management '
        },
        component: () => import('@/views/enterprise/systemManagement/userManagement/index.vue')
      }
    ]
  },
  {
    path: '/enterprise/enterpriseCenter',
    component: Layout,
    name: 'enterpriseCenter',
    show: true,
    meta: {
      title: '企业中心'
    },
    children: [
      {
        path: '/enterprise/enterpriseCenter',
        show: true,
        component: () => import('@/views/enterprise/enterpriseCenter/index.vue'),
        meta: {
          title: '企业中心',
          hideSide: true
        }
      }
    ]
  }
]
export default enterprise